pub fn warhead_arm()Expand description
Arm the warhead on the current vehicle, this means that the warhead will explode when this vehicle is destroyed
pub fn warhead_arm()Arm the warhead on the current vehicle, this means that the warhead will explode when this vehicle is destroyed